.. _filters:

#########
 Filters
#########

.. warning::

   This is still a work in progress. Some of the filters may be renamed
   later.

Filters are used to modify the data or metadata in a dataset.

.. toctree::
   :maxdepth: 1

   filters/select
   filters/rename
   filters/rotate_winds
   filters/unrotate_winds
   filters/noop
   filters/empty
